import path from 'path';
import findRoot from 'find-root';

const root = findRoot(process.cwd());

export default function ({ types: t }) {
  return {
    visitor: {
      CallExpression({ node }, { opts, file }) {
        if (node.callee.name !== 'require' || node.arguments.length !== 1 ||
          !t.isStringLiteral(node.arguments[0])) return;
        const { value } = node.arguments[0];
        const { ignore = [], baseDir = '' } = opts;
        if (value.startsWith('.') || ignore.indexOf(value) !== -1) return;
        try {
          require(value); // eslint-disable-line
        } catch (e) {
          if (e.message.slice(0, 18) === 'Cannot find module') {
            const { filename } = file.opts;
            node.arguments[0].value = './' + path.relative(path.dirname(filename), path.join(root, baseDir, value)); // eslint-disable-line
          }
        }
      },
    },
  };
}
